Learn R Programming

paleoTS (version 0.5.3)

cantius_L: Time-series of the length of lower first molar for the Cantius lineage

Description

Time-series of the length of lower first molar for the Cantius lineage

Usage

cantius_L

Arguments

Format

a paleoTS object with the data