D = Vstep/(2Vp), where Vstep is the
step variance of the unbiased random walk, and Vp is the within sample variance, pooled among samples. Under mutation - drift equilibrium, D is expected to range
approximately between 5e-5 and 5e-3.lynchD(y, gen.per.t = 1e+06, pool = TRUE, method=c('AD', 'Joint'), ...)paleoTS objectVstepopt.URW or opt.joint.URWVstep, at the original time scale of yD consistent with neutral evoltuiongen.per.t argument indicates the number of organismal generations for each unit of time with which the time-series y was measured. For example, is y$tt is measured in millions of years, and the species has annual generations, gen.per.t would be 1e6.
For difference between the method choices, see Hunt (2008).
Estimation of Vstep is done on the original time scale of y, and then the values are converted to generational time scales using gen.per.t. This is for numerical reasons, as it avoids computations on possible very low numbers.opt.URWy<- sim.GRW(ns=20, ms=0, vs=1e-4, tt=seq(0,1e6, length.out=20)) # per-year simulation
lynchD(y, gen.per.t=1) # 1 generation per yearRun the code above in your browser using DataLab