if TRUE, return standard errors of parameter estimates from the
hessian matrix
Functions
opt.joint.URW(): fit the URW model by the Joint parameterization
opt.joint.Stasis(): fit the Stasis model by the Joint parameterization
opt.joint.StrictStasis(): fit the Strict Stasis model by the Joint parameterization
Details
These functions use the joint distribution of population means to fit models
using a full maximum-likelihood approach. This approach was found to have somewhat
better performance than the "AD" approach, especially for noisy trends (Hunt, 2008).
References
#' Hunt, G., M. J. Hopkins and S. Lidgard. 2015. Simple versus complex models of trait evolution
and stasis as a response to environmental change. PNAS 112(16): 4885-4890.